<template>
  <el-container>
    <el-main>
      <basic-container>
        <avue-crud v-model="form" ref="crud" :option="option" :data="data" @on-load="onLoad" :page.sync="page"
                   @search-change="searchChange"
                   @search-reset="searchReset"
                   @selection-change="selectionChange"
                   @current-change="currentChange"
                   @size-change="sizeChange"
                   @refresh-change="refreshChange" @row-click="rowClick">
          <template slot="menu" slot-scope="{row,index}">
            <el-button icon="el-icon-edit" size="small" type="text" @click="updateSave(row,index)">编辑</el-button>
            <el-button icon="el-icon-delete" size="small" type="text" @click="deleteSave(row,index)">删除</el-button>
            <el-button v-if="row.usedflag=='false'" icon="el-icon-position" size="small" type="text" @click="ENABLE(row,index)">启用</el-button>
            <el-button v-else icon="el-icon-finished" size="small" type="text" @click="DISABLE(row,index)">停用</el-button>
          </template>
          <template slot="menuLeft">
            <el-button size="small" type="primary" icon="el-icon-plus" @click="addSave">新&nbsp;&nbsp;增
            </el-button>
            <el-button size="small" icon="el-icon-share" @click="PUSH">同  步
            </el-button>
            <el-button size="small" icon="el-icon-search" @click="openAdvancedQuery">查  询
            </el-button>
          </template>
        </avue-crud>
      </basic-container>
    </el-main>
    <infoForm ref="infoForm" @refreshTable="refreshChange" :formData="editAttribute"></infoForm>
    <!-- 高级查询对话框 -->
    <advanced-query
      :ref="advancedQueryParam.ref"
      :options="advancedQueryParam.options"
      :visible.sync="advancedQueryParam.advancedQuerySettingBox"
      @echoContion="echoSeniorContionMap">
    </advanced-query>
  </el-container>
</template>

<script>
import {
  getList,add,edit,del,push,updateStatus
} from "@/api/docking/info";
import {getDictionary} from "@/api/omd/enum";
import infoForm from "./infoForm.vue";

export default {
  name: "info",
  components:{infoForm},
  data() {
    return {
      //接口类型下拉
      interfaceTypeList: [{
        label: 'webService', value: 'webService'
      }, {
        label: '类路径', value: 'classPath'
      }, {
        label: 'Http', value: 'http'
      }],
      //参数类型下拉
      paramTypeList: [{
        label: 'xml', value: 'xml'
      }, {
        label: 'Json', value: 'json'
      }],
      //返回值类型下拉
      returnTypeList: [{
        label: 'xml', value: 'xml'
      }, {
        label: 'Json', value: 'json'
      }],
      //推送类型
      pushTypeList: [{value: '1', label: '数据推送'},
        {value: '2', label: '分类推送'},
        {value: '3', label: '编码申请'},
        {value: '4', label: '编码更改（状态、回收）'},
        {value: '5', label: '分类查询'},
        {value: '6', label: '含规则信息的分类查询'},
        {value: '7', label: '数据查询'}],
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 100
      },
      selectRow: {},
      data: [],
      form: {},
      editAttribute: {},
      selectionList: [],
      option: {
        height: "auto",
        calcHeight: 20,
        tip: false,
        headerAlign: "center",
        border: true,
        index: true,
        selection: true,
        searchShow: false,
        searchMenuSpan: 6,
        rowKey: "id",
        tabs: true,
        stripe: true,
        indexFixed: false,
        menuWidth: 180,
        highlightCurrentRow: true,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        columnBtn: false,
        column: [{
          label: '推送类型',
          prop: 'pushType',
          sortable: true,
          width: 150,
          formatter:function (d){
            return this.pushTypeList[d.pushType]
          }
        }, {
          label: '系统编号',
          prop: 'id',
          sortable: true,
          width: 150
        }, {
          label: '系统名称',
          prop: 'name',
          sortable: true,
          width: 150
        }, {
          label: '接口函数',
          prop: 'interfaceFunction',
          sortable: true,
          width: 150
        }, {
          label: '命名空间',
          prop: 'nameSpace',
          sortable: true,
          width: 150
        }, {
          label: 'soapAction',
          prop: 'soapAction',
          sortable: true,
          width: 150
        }, {
          label: '参数名称',
          prop: 'targName',
          sortable: true,
          width: 150
        }, {
          label: '调用方式',
          prop: 'cxfaxis',
          sortable: true,
          width: 150
        }, {
          label: '请求地址',
          prop: 'requestUrl',
          sortable: true,
          width: 150
        }, {
          label: '参数类型',
          prop: 'paramType',
          sortable: true,
          width: 150,
          formatter:function (d){
            return this.paramTypeList[d.paramType]
          }
        }, {
          label: '返回值类型',
          prop: 'returnType',
          sortable: true,
          width: 150,
          formatter:function (d){
            return this.returnTypeList[d.returnType]
          }
        }, {
          label: '系统描述',
          prop: 'description',
          width: 150
        }]
      },
      // 高级查询对话框相关参数
      advancedQueryParam: {
        ref: 'advancedQuery',
        advancedQuerySettingBox: false,
        options: [],
        currentOpen: '', //当前打开高级查询的窗口是
        //conditionMapParams: {},
      }
    };
  },
  created() {
  },
  computed: {
    oids() {
      let oids = [];
      this.selectionList.forEach(ele => {
        oids.push(ele.oid);
      });
      return oids.join(",");
    }
  },
  methods: {
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
      if(this.selectionList.length <= 0){
        this.selectRow = null
      }
      if (this.selectionList.length > 0) {
        this.selectRow = this.selectionList[list.length-1].$index;
      }
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page, this.query);
    },
    addSave() {
      this.$refs.infoForm.showSubmitDialog = true;
      this.$refs.infoForm.formData = {
        dataFlowType:'push',
        pushType:'1',
        sourceSystemName:'编码系统',
        sourceSystemOid:'code00000001',
        sourceSystemId:'CODE',
        targetSystemName:'',
        targetSystemOid:'',
        targetSystemId:'',
        sysIntParamVOs:[],
        sysIntHeaderVOs:[]
      };
    },
    updateSave(row,index) {
      this.selectRow = row;
      this.editAttribute = row;
      this.editAttribute.sysIntParamVOs = row.sysIntParamVOs||[];
      this.editAttribute.sysIntHeaderVOs = row.sysIntHeaderVOs||[];
      this.$refs.infoForm.formData = this.editAttribute;
      this.$refs.infoForm.showSubmitDialog = true;
    },
    deleteSave(row,index) {
      this.$confirm("删除数据将无法被恢复, 是否继续?", "提示", {
        iconClass: 'el-icon-question',
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        showClose: true,
        type: "warning"
      }).then(() => {
        remove(row.oid).then(res => {
          this.$message.success("删除成功");
          this.refreshChange();
        });
      });
    },
    ENABLE(row,index){
      //启用
      this.updateStatus(row,"enable");
    },
    DISABLE(row,index){
      //停用
      this.updateStatus(row,"disable");
    },
    updateStatus(selectRow,able){
      var that = this;
      var paramTemp = {
        update:able,
        oid:selectRow.oid,
        ts:selectRow.ts
      };
      this.$confirm("是否要"+(able == "enbale" ? "启用" : (able == "disable" ? "停用": "发布")) +"这条数据？", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return updateStatus(paramTemp);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message:(able == "enbale" ? "启用成功" : (able == "disable" ? "停用成功": "发布成功"))
          });
        });
    },
    PUSH(){
      if (this.selectionList.length != 1) {
        this.$message.warning('请选择数据')
        return false;
      }
      this.$confirm("是否要"+ (this.selectionList[0].pushType == "1" ? "推送数据" : "推送分类"), {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return push(this.oids.split(','));
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          this.$refs.crud.toggleSelection();
        });
    },
    onLoad(page, params = {}) {
      this.loading = true;
      getList(this.page.currentPage, this.page.pageSize, Object.assign(params, this.query)).then(res => {
        const data = res.data.data;
        debugger;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
      });
    },
    rowClick(row) {
      this.selectRow = row;
      this.$refs.crud.toggleSelection();
      this.$refs.crud.toggleRowSelection(row); //选中当前行
    },
    /** 高级查询对话框组件,组件返回的值是condtionMap[field]形式的查询条件，保留了和之前一样的方式 */
    echoSeniorContionMap(conditionMaps){
      if(JSON.stringify(conditionMaps)!='{}'){
        this.query = conditionMaps;
        this.onLoad(this.page);
      }
    },
    openAdvancedQuery(){
        this.advancedQueryParam.options = [{
          data: this.pushTypeList,
          title: '推送类型',
          queryField: 'pushType',
          fieldType: 'combox',
          comboxKey: 'searchPushType'
        }, {
          title: '系统名称',
          queryField: 'sysBaseName',
          fieldType: 'text'
        }, {
          title: '系统编号',
          queryField: 'sysBaseId',
          fieldType: 'text'
        }, {
          title: '接口函数',
          queryField: 'interfaceFunction',
          fieldType: 'text'
        }, {
          title: '命名空间',
          queryField: 'nameSpace',
          fieldType: 'text'
        }, {
          title: 'soapAction',
          queryField: 'soapAction',
          fieldType: 'text'
        }, {
          title: '参数名称',
          queryField: 'targName',
          fieldType: 'text'
        }, {
          title: '调用方式',
          queryField: 'cxfaxis',
          fieldType: 'text'
        }, {
          title: '请求地址',
          queryField: 'requestUrl',
          fieldType: 'text'
        }, {
          title: '参数类型',
          queryField: 'paramType',
          fieldType: 'combox',
          comboxKey: 'searchparamType',
          data:this.paramTypeList
        }, {
          title: '返回值类型',
          queryField: 'returnType',
          fieldType: 'combox',
          comboxKey: 'searchreturnType',
          data:this.returnTypeList
        }]

      this.advancedQueryParam.currentOpen = 'info';
      this.advancedQueryParam.advancedQuerySettingBox = true;
    },
  }
}
</script>

<style lang="scss">
.applyRangeTable>.el-card:nth-of-type(2)>.el-card__body>.avue-crud__menu {
  display: none !important;
}
</style>
